
### Project description
Faclon I/O Sense Data Access Library
​
#### Where to get it
https://pypi.org/project/iosense/

#### Installation
pip install iosense

pip3 install iosense

#### Features
Retrives following details:

- User information.
- Device Details.
- Device metaData.
- Time based sensor data of a Device. 
- Published events details.
- Events data in given timeslot.
- Event categories.
- Events data count.

#### Dependencies

+ pandas
+ requests
+ json 
+ time 
+ datetime 


#### Documentation
The official documentation is hosted on​ 

#### Reach us
For usage questions, please reach out to us at reachus@faclon.com